#!/usr/bin/env node
import { defineComposerOptions, defineComposerConfig, generateComposerInfo, categories, defineComposerChecks, defineComposerTests, defineComposer } from '@svelte-compose/core';

var name = "@svelte-compose/tailwindcss";
var version = "0.2.4";
var bin = "build/index.js";
var type = "module";
var license = "MIT";
var dependencies = {
	"@svelte-compose/core": "workspace:*"
};
var bugs = "https://github.com/svelte-compose/svelte-compose/issues";
var repository = {
	type: "git",
	url: "https://github.com/svelte-compose/svelte-compose/tree/main/projects/composers/tailwindcss"
};
var keywords = [
	"tailwind",
	"postcss",
	"autoprefixer",
	"svelte",
	"kit",
	"svelte-kit"
];
var pkg = {
	name: name,
	version: version,
	bin: bin,
	type: type,
	license: license,
	dependencies: dependencies,
	bugs: bugs,
	repository: repository,
	keywords: keywords
};

const options = defineComposerOptions({
    typography: {
        question: "Do you want to use typography plugin?",
        default: false,
        type: "boolean",
    },
});

const composer = defineComposerConfig({
    metadata: {
        ...generateComposerInfo(pkg),
        name: "TailwindCSS",
        description: "Rapidly build modern websites without ever leaving your HTML.",
        category: categories.styling,
        environments: { svelte: true, kit: true },
        website: {
            logo: "./tailwindcss.svg",
            keywords: ["tailwind", "postcss", "autoprefixer"],
            documentation: "https://tailwindcss.com/docs/",
        },
    },
    options,
    packages: [
        { name: "tailwindcss", version: "^3.4.1", dev: true },
        { name: "postcss", version: "^8.4.33", dev: true },
        { name: "autoprefixer", version: "^10.4.16", dev: true },
        { name: "@tailwindcss/typography", version: "^0.5.10", dev: true, condition: ({ options }) => options.typography },
        {
            name: "prettier-plugin-tailwindcss",
            version: "^0.5.1",
            dev: true,
            condition: ({ prettier }) => prettier.installed,
        },
    ],
    files: [
        {
            name: ({ typescript }) => `tailwind.config.${typescript.installed ? "ts" : "js"}`,
            contentType: "script",
            content: ({ options, ast, array, object, common, functions, exports }) => {
                const { astNode: exportDeclaration, value: rootExport } = exports.defaultExport(ast, object.createEmpty());

                common.addJsDocTypeComment(exportDeclaration, "import('tailwindcss').Config");

                const contentArray = object.property(rootExport, "content", array.createEmpty());
                array.push(contentArray, "./src/**/*.{html,js,svelte,ts}");

                const themeObject = object.property(rootExport, "theme", object.createEmpty());
                object.property(themeObject, "extend", object.createEmpty());

                const pluginsArray = object.property(rootExport, "plugins", array.createEmpty());

                if (options.typography) {
                    const requireCall = functions.call("require", ["@tailwindcss/typography"]);
                    array.push(pluginsArray, requireCall);
                }
            },
        },
        {
            name: () => "postcss.config.js",
            contentType: "script",
            content: ({ ast, object, exports }) => {
                const { value: rootObject } = exports.defaultExport(ast, object.createEmpty());
                const pluginsObject = object.property(rootObject, "plugins", object.createEmpty());

                object.property(pluginsObject, "tailwindcss", object.createEmpty());
                object.property(pluginsObject, "autoprefixer", object.createEmpty());
            },
        },
        {
            name: () => "src/app.css",
            contentType: "css",
            content: ({ ast, addAtRule }) => {
                const atRules = ["base", "components", "utilities"];
                for (const name of atRules) {
                    addAtRule(ast, "tailwind", name);
                }
            },
        },
        {
            name: () => "src/App.svelte",
            contentType: "svelte",
            content: ({ js }) => {
                js.imports.addEmpty(js.ast, "./app.css");
            },
            condition: ({ kit }) => !kit.installed,
        },
        {
            name: ({ kit }) => `${kit.routesDirectory}/+layout.js`,
            contentType: "script",
            content: ({ ast, imports }) => {
                imports.addEmpty(ast, "../app.css");
            },
            condition: ({ kit }) => kit.installed,
        },
        {
            name: () => ".prettierrc",
            contentType: "json",
            content: ({ data }) => {
                if (!data.plugins) data.plugins = [];

                data.plugins.push("prettier-plugin-tailwindcss");
            },
            condition: ({ prettier }) => prettier.installed,
        },
    ],
});

const checks = defineComposerChecks({
    options,
    postInstallation: [],
});

const divId = "myDiv";
const typographyDivId = "myTypographyDiv";

const tests = defineComposerTests({
    files: [
        {
            name: ({ kit }) => `${kit.routesDirectory}/+page.svelte`,
            contentType: "svelte",
            content: (editor) => {
                prepareCoreTest(editor);
                if (editor.options.typography) prepareTypographyTest(editor);
            },
            condition: ({ kit }) => kit.installed,
        },
        {
            name: () => `src/App.svelte`,
            contentType: "svelte",
            content: (editor) => {
                prepareCoreTest(editor);
                if (editor.options.typography) prepareTypographyTest(editor);
            },
            condition: ({ kit }) => !kit.installed,
        },
    ],
    options,
    optionValues: [{ typography: false }, { typography: true }],
    tests: [
        {
            name: "core properties",
            run: async ({ expectProperty }) => {
                const selector = "#" + divId;
                await expectProperty(selector, "background-color", "rgb(71, 85, 105)");
                await expectProperty(selector, "border-color", "rgb(249, 250, 251)");
                await expectProperty(selector, "border-width", "4px");
                await expectProperty(selector, "margin-top", "4px");
            },
        },
        {
            name: "typography properties",
            condition: ({ typography }) => typography,
            run: async ({ expectProperty }) => {
                const selector = "#" + typographyDivId;
                await expectProperty(selector, "font-size", "18px");
                await expectProperty(selector, "line-height", "28px");
                await expectProperty(selector, "text-align", "right");
                await expectProperty(selector, "text-decoration-line", "line-through");
            },
        },
    ],
});

/**
 * @template {import("@svelte-compose/core/composer/options.js").OptionDefinition} Args
 * @param {import("@svelte-compose/core/files/processors.js").SvelteFileEditorArgs<Args>} editor
 */
function prepareCoreTest({ html }) {
    const div = html.div({ class: "bg-slate-600 border-gray-50 border-4 mt-1", id: divId });
    html.appendElement(html.ast.childNodes, div);
}

/**
 * @template {import("@svelte-compose/core/composer/options.js").OptionDefinition} Args
 * @param {import("@svelte-compose/core/files/processors.js").SvelteFileEditorArgs<Args>} editor
 */
function prepareTypographyTest({ html }) {
    const div = html.element("p", { class: "text-lg text-right line-through", id: typographyDivId });
    html.appendElement(html.ast.childNodes, div);
}

var index = defineComposer(composer, checks, tests);

export { index as default };
//# sourceMappingURL=index.js.map
